@@ -13,6 +13,8 @@
 #include "control/controlutil.h"
 #include "control/controlid.h"
 
+#include "icons/iconmanager.h"
+
 #include "command.h"
 #include "session.h"
 #include "compmanager.h"
@@ -24,7 +26,8 @@ using namespace BBSLIST;
 BBSListToolBar::BBSListToolBar() :
     SKELETON::ToolBar( BBSLIST::get_admin() ),
     m_button_toggle( "板一覧とお気に入りの切り替え", true, true, m_label ),
-    m_button_check_update_root( NULL )
+    m_button_check_update_root( NULL ),
+    m_button_check_update_open_root( NULL )
 {
     m_button_toggle.get_button()->set_tooltip_arrow( "板一覧とお気に入りの切り替え\n\nマウスホイール回転でも切り替え可能" );
 
@@ -46,7 +49,7 @@ BBSListToolBar::BBSListToolBar() :
     pack_start( m_tool_label, Gtk::PACK_SHRINK );
 
     pack_buttons();
-    add_search_mode( CONTROL::MODE_BBSLIST );
+    add_search_control_mode( CONTROL::MODE_BBSLIST );
 }
 
 
@@ -63,7 +66,7 @@ void BBSListToolBar::pack_buttons()
         switch( item ){
 
             case ITEM_SEARCHBOX:
-                get_buttonbar().append( *get_entry_search( CORE::COMP_SEARCH_BBSLIST ) );
+                get_buttonbar().append( *get_tool_search( CORE::COMP_SEARCH_BBSLIST ) );
                 break;
 
             case ITEM_CHECK_UPDATE_ROOT:
@@ -75,6 +78,15 @@ void BBSListToolBar::pack_buttons()
                 get_buttonbar().append( *m_button_check_update_root );
                 break;
 
+            case ITEM_CHECK_UPDATE_OPEN_ROOT:
+                if( ! m_button_check_update_open_root ){
+                    m_button_check_update_open_root = Gtk::manage( new SKELETON::ImgToolButton( ICON::THREAD ) );
+                    m_button_check_update_open_root->signal_clicked().connect( sigc::mem_fun(*this, &BBSListToolBar::slot_check_update_open_root ) );
+                    set_tooltip( *m_button_check_update_open_root, CONTROL::get_label_motions( CONTROL::CheckUpdateOpenRoot ) );
+                }
+                get_buttonbar().append( *m_button_check_update_open_root );
+                break;
+
             case ITEM_SEARCH_NEXT:
                 get_buttonbar().append( *get_button_down_search() );
                 break;
@@ -144,3 +156,40 @@ void BBSListToolBar::slot_check_update_root()
 {
     CORE::core_set_command( "check_update_root", "" );
 }
+
+
+void BBSListToolBar::slot_check_update_open_root()
+{
+    CORE::core_set_command( "check_update_open_root", "" );
+}
+
+
+
+////////////////////////////////////////
+
+
+EditListToolBar::EditListToolBar() :
+    SKELETON::ToolBar( NULL )
+{
+    pack_buttons();
+}
+
+
+//
+// ボタンのパッキング
+//
+// virtual
+void EditListToolBar::pack_buttons()
+{
+    get_buttonbar().append( *get_tool_search( CORE::COMP_SEARCH_BBSLIST ) );
+    get_buttonbar().append( *get_button_down_search() );
+    get_buttonbar().append( *get_button_up_search() );
+    add_search_control_mode( CONTROL::MODE_BBSLIST );
+
+    get_buttonbar().append( *get_button_undo() );
+    get_buttonbar().append( *get_button_redo() );
+    get_buttonbar().append( *get_button_close() );
+
+    set_relief();
+    show_all_children();
+}
