@@ -122,7 +122,7 @@ namespace CONTROL
         { "OpenBoardTabButton", "タブで板を開く" },
 
         { "CheckUpdateRoot", ITEM_NAME_CHECK_UPDATE_ROOT },
-        { "CheckUpdateOpenRoot", "更新されたスレをタブで開く" },
+        { "CheckUpdateOpenRoot", ITEM_NAME_CHECK_UPDATE_OPEN_ROOT },
 
         { "", "" },
 
@@ -163,6 +163,10 @@ namespace CONTROL
         { "LiveStartStop", ITEM_NAME_LIVE },
 
         { "SearchNextArticle", "次スレ検索" },
+        { "SearchWeb", "" },  //  CONTROL::get_keyconfig() で名前をセットする
+        { "SearchTitle", "" }, //  CONTROL::get_keyconfig() で名前をセットする
+        { "SearchCacheLocal", "ログ検索(対象: 板)" },
+        { "SearchCacheAll", "ログ検索(対象: 全ログ)" },
 
         { "PopupWarpButton", "クリックで多重ポップアップモードに移行" },
         { "ReferResButton", "参照レスポップアップ表示" },
